@@ -118,10 +118,11 @@ def get_challenge_with_params(key: str, value: str, api_key: str) -> dict:
 
     try:
         return r.json()[0]
-    except json.JSONDecodeError as e:
+    except (json.JSONDecodeError, IndexError) as e:
         log.error("Parsing response failed\n%s", e)
         raise ChallengeNotFoundException(
-            "Error in decoding the response from API"
+            "Error in decoding the response from AIcrowd servers",
+            "Please recheck the challenge name",
         ) from e
 
 
