@@ -8,6 +8,7 @@ import click
 
 from aicrowd.contexts import pass_config, ConfigContext
 from aicrowd.utils import AliasedGroup
+from aicrowd.utils.utils import exception_handler
 
 
 @click.group(name="challenge", cls=AliasedGroup)
@@ -31,6 +32,7 @@ def challenge_command():
     help="Create a new directory for challenge inside current directory",
 )
 @pass_config
+@exception_handler
 def init_subcommand(
     config_ctx: ConfigContext, challenge: str, base_dir: str, mkdir: bool
 ):
@@ -38,15 +40,8 @@ def init_subcommand(
     Setups basic challenge files
     """
     from aicrowd.challenge import init_challenge
-    from aicrowd.challenge.exceptions import ChallengeException
 
-    try:
-        init_challenge(challenge, base_dir, mkdir, config_ctx)
-    except ChallengeException as e:
-        click.echo(click.style(e.message, fg="red"))
-        if e.fix:
-            click.echo(click.style(e.fix, fg="yellow"))
-        sys.exit(e.exit_code)
+    init_challenge(challenge, base_dir, mkdir, config_ctx)
 
 
 challenge_command.add_command(init_subcommand)
