@@ -8,9 +8,12 @@ import os
 from concurrent.futures import ThreadPoolExecutor
 from functools import partial
 from typing import Dict, Iterable, List
+from urllib.error import HTTPError
 from urllib.parse import urlparse
 from urllib.request import Request, urlopen
 
+import click
+
 # pylint: disable=unused-import
 from aicrowd.challenge.helpers import must_get_api_key, parse_cli_challenge
 
@@ -119,6 +122,8 @@ class Downloader:
         self.__active = False
         self.chunk_size = self.get_chunk_size(chunk_size)
 
+        self.log = logging.getLogger()
+
     @staticmethod
     def get_chunk_size(chunk_size: int) -> int:
         """
@@ -143,7 +148,13 @@ class Downloader:
         req = Request(url)
         if urlparse(url).netloc == DATASETS_HOST:
             req.add_unredirected_header("Authorization", f"Token {self.api_key}")
-        response = urlopen(req)
+
+        try:
+            response = urlopen(req)
+        except HTTPError as e:
+            self.log.error("Error in downloading dataset %s.\n%s", url, e)
+            click.echo(click.style(f"Error in downloading dataset {url}", fg="red"))
+            return
 
         # This will break if the response doesn't contain content length
         task_id = self.progress_bar.add(
@@ -159,6 +170,8 @@ class Downloader:
 
                 dest_file.write(data)
                 self.progress_bar.update(progress_bar_id=task_id, step=len(data))
+
+        self.log.info("File %s downloaded successfully", dest_file)
         self.progress_bar.close(progress_bar_id=task_id)
 
     def download(self, urls: Iterable[str], dest_dir: str):
