@@ -11,6 +11,12 @@ class NotebookException(CLIException):
     """
 
 
+class NotebookAppImportException(NotebookException):
+    """
+    Exception for notebook app import errors
+    """
+
+
 class InvalidJupyterResponse(NotebookException):
     """
     Exception for bad responses from jupyter REST API
