@@ -1,6 +1,7 @@
 from aicrowd.utils.utils import (
     is_subsequence,
     AliasedGroup,
+    CommandWithExamples,
     RichProgressBar,
     TqdmProgressBar,
 )
@@ -8,6 +9,7 @@ from aicrowd.utils.utils import (
 __all__ = [
     "is_subsequence",
     "AliasedGroup",
+    "CommandWithExamples",
     "RichProgressBar",
     "TqdmProgressBar",
 ]
